==> jc-1.4.0.tar.gz: gnu/xml/dom/DomProcessingInstruction.h <==
// public class gnu.xml.dom.DomProcessingInstruction

// class file dependencies
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 989c526d685a0284 gnu_xml_dom_DomProcessingInstruction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomProcessingInstruction_H_
#define _JC_gnu_xml_dom_DomProcessingInstruction_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_refs	_jc_gnu_xml_dom_DomProcessingInstruction$sub_refs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs	_jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$refs	_jc_gnu_xml_dom_DomProcessingInstruction$refs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$nonrefs	_jc_gnu_xml_dom_DomProcessingInstruction$nonrefs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$object	_jc_gnu_xml_dom_DomProcessingInstruction$object;

typedef const struct _jc_gnu_xml_dom_DomProcessingInstruction$vmethods	_jc_gnu_xml_dom_DomProcessingInstruction$vmethods;
typedef const struct _jc_gnu_xml_dom_DomProcessingInstruction$vtable	_jc_gnu_xml_dom_DomProcessingInstruction$vtable;
typedef const struct _jc_gnu_xml_dom_DomProcessingInstruction$vtype	_jc_gnu_xml_dom_DomProcessingInstruction$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomProcessingInstruction$method$_init$5ae85a8c824cdcc2(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getNodeValue$651f544cf23da22a(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getTarget$12ef98d215594559(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
extern void _jc_gnu_xml_dom_DomProcessingInstruction$method$setData$659a7707842e4261(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_dom_DomProcessingInstruction$method$setNodeValue$83f7cbb63600100e(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getNodeName$f5b11134ac79aed1;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getNodeValue$651f544cf23da22a;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getTarget$12ef98d215594559;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$setData$659a7707842e4261;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$setNodeValue$83f7cbb63600100e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomProcessingInstruction$vmethods {
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
	struct _jc_java_lang_String$object	*(*getNodeValue$651f544cf23da22a)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
	struct _jc_java_lang_String$object	*(*getTarget$12ef98d215594559)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *);
	void	(*setData$659a7707842e4261)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *);
	void	(*setNodeValue$83f7cbb63600100e)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomProcessingInstruction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomProcessingInstruction$vmethods	gnu_xml_dom_DomProcessingInstruction;
};

// Vtype
struct _jc_gnu_xml_dom_DomProcessingInstruction$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomProcessingInstruction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_refs {
	struct _jc_java_lang_String$object	*target;
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomProcessingInstruction$refs {
    _jc_gnu_xml_dom_DomProcessingInstruction$sub_refs	gnu_xml_dom_DomProcessingInstruction;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomProcessingInstruction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs	gnu_xml_dom_DomProcessingInstruction;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomProcessingInstruction$object {
	_jc_gnu_xml_dom_DomProcessingInstruction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomProcessingInstruction$vtype	*vtype;
	_jc_gnu_xml_dom_DomProcessingInstruction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomProcessingInstruction$vtype _jc_gnu_xml_dom_DomProcessingInstruction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomProcessingInstruction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomProcessingInstruction$class_object;

#endif	/* _JC_gnu_xml_dom_DomProcessingInstruction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomProcessingInstruction.h <==
// public class gnu.xml.dom.DomProcessingInstruction

// class file dependencies
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 989c526d685a0284 gnu_xml_dom_DomProcessingInstruction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomProcessingInstruction_H_
#define _JC_gnu_xml_dom_DomProcessingInstruction_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_refs	_jc_gnu_xml_dom_DomProcessingInstruction$sub_refs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs	_jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$refs	_jc_gnu_xml_dom_DomProcessingInstruction$refs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$nonrefs	_jc_gnu_xml_dom_DomProcessingInstruction$nonrefs;
typedef struct _jc_gnu_xml_dom_DomProcessingInstruction$object	_jc_gnu_xml_dom_DomProcessingInstruction$object;

typedef const struct _jc_gnu_xml_dom_DomProcessingInstruction$vmethods	_jc_gnu_xml_dom_DomProcessingInstruction$vmethods;
typedef const struct _jc_gnu_xml_dom_DomProcessingInstruction$vtable	_jc_gnu_xml_dom_DomProcessingInstruction$vtable;
typedef const struct _jc_gnu_xml_dom_DomProcessingInstruction$vtype	_jc_gnu_xml_dom_DomProcessingInstruction$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomProcessingInstruction$method$_init$5ae85a8c824cdcc2(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getNodeValue$651f544cf23da22a(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomProcessingInstruction$method$getTarget$12ef98d215594559(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomProcessingInstruction$method$setData$659a7707842e4261(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomProcessingInstruction$method$setNodeValue$83f7cbb63600100e(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getNodeName$f5b11134ac79aed1;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getNodeValue$651f544cf23da22a;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$getTarget$12ef98d215594559;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$setData$659a7707842e4261;
extern _jc_method _jc_gnu_xml_dom_DomProcessingInstruction$method_info$setNodeValue$83f7cbb63600100e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomProcessingInstruction$vmethods {
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNodeValue$651f544cf23da22a)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTarget$12ef98d215594559)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *) _JC_JCNI_ATTR;
	void	(*setData$659a7707842e4261)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setNodeValue$83f7cbb63600100e)(_jc_env *, struct _jc_gnu_xml_dom_DomProcessingInstruction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomProcessingInstruction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomProcessingInstruction$vmethods	gnu_xml_dom_DomProcessingInstruction;
};

// Vtype
struct _jc_gnu_xml_dom_DomProcessingInstruction$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomProcessingInstruction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_refs {
	struct _jc_java_lang_String$object	*target;
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomProcessingInstruction$refs {
    _jc_gnu_xml_dom_DomProcessingInstruction$sub_refs	gnu_xml_dom_DomProcessingInstruction;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomProcessingInstruction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomProcessingInstruction$sub_nonrefs	gnu_xml_dom_DomProcessingInstruction;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomProcessingInstruction$object {
	_jc_gnu_xml_dom_DomProcessingInstruction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomProcessingInstruction$vtype	*vtype;
	_jc_gnu_xml_dom_DomProcessingInstruction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomProcessingInstruction$vtype _jc_gnu_xml_dom_DomProcessingInstruction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomProcessingInstruction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomProcessingInstruction$class_object;

#endif	/* _JC_gnu_xml_dom_DomProcessingInstruction_H_ */
